
// algorithm is required for min and max
#include <algorithm>

#include "gui/UI.h"
#include "dsp/one-sample-dsp.h"

using namespace std;

struct Meta {
	void declare(const char*, const char*) {}
};
